@@ -11,12 +11,12 @@ use crate::config::{Config, IGNORED_CONFIG_FILES};
 use crate::env::PATH_KEY;
 use crate::file::display_path;
 use crate::git::Git;
-use crate::plugins::core::CORE_PLUGINS;
 use crate::plugins::PluginType;
+use crate::plugins::core::CORE_PLUGINS;
 use crate::toolset::{ToolVersion, Toolset, ToolsetBuilder};
 use crate::ui::{info, style};
 use crate::{backend, cmd, dirs, duration, env, file, shims};
-use console::{pad_str, style, Alignment};
+use console::{Alignment, pad_str, style};
 use heck::ToSnakeCase;
 use indexmap::IndexMap;
 use indoc::formatdoc;
